/* 
 * i-scream central monitoring system
 * http://www.i-scream.org.uk
 * Copyright (C) 2000-2002 i-scream
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

//---PACKAGE DECLARATION---
package uk.org.iscream.cms.server.client.monitors;

//---IMPORTS---
import uk.org.iscream.cms.server.client.*;
import uk.org.iscream.cms.server.core.*;
import uk.org.iscream.cms.util.*;
import uk.org.iscream.cms.server.componentmanager.*;

/**
 * Provides a full XMLPacket feed to the WebFeeder
 *
 * @author  $Author: tdb $
 * @version $Id: WebFeeder__Monitor.java,v 1.10 2003/02/05 16:43:46 tdb Exp $
 */
public class WebFeeder__Monitor extends Thread implements PluginMonitor {

//---FINAL ATTRIBUTES---

    /**
     * The current CVS revision of this class
     */
    public static final String REVISION = "$Revision: 1.10 $";
    
    /**
     * A description of this monitor
     */
    public static final String DESC = "Provides a feed to WebFeeder";
    
//---STATIC METHODS---

//---CONSTRUCTORS---
    
    /**
     * Constructs a new instance of this hook for the WebFeeder.
     */
    public WebFeeder__Monitor() {
        this.start();
    }

//---PUBLIC METHODS---
    
    /**
     * Keeps getting packets from the queue, and analyses
     * them. In reality, this just sends them off to the
     * WebFeeder for further processing.
     */
    public void run() {
        while(_running) {
            try {
                analysePacket((XMLPacket) getQueue().get(getQueueId()));
            } catch (InvalidQueueException e) {
                _logger.write(this.toString(), Logger.ERROR, "Unable to get queue.");
            }
        }
    }
    
    /**
     * Sends a packet to the WebFeeder for processing, if
     * we are active.
     *
     * @param packet the XMLPacket to send to the WebFeeder
     */
    public void analysePacket(XMLPacket packet) {
        try {
            ConfigurationProxy.getInstance().getProperty("WebFeeder", "WebFeeder.latestActive");
            WebFeeder.getInstance().receiveXMLPacket(packet);
        } catch (PropertyNotFoundException e) {
            // we don't care, this means we shouldn't be active
        }
    }
    
    /**
     * return the String representation of what the monitor does
     */
    public String getDescription() {
        return DESC;
    }

    /**
     * Overrides the {@link java.lang.Object#toString() Object.toString()}
     * method to provide clean logging (every class should have this).
     *
     * This uses the uk.org.iscream.cms.util.FormatName class
     * to format the toString()
     *
     * @return the name of this class and its CVS revision
     */
    public String toString() {
        return FormatName.getName(
            _name,
            getClass().getName(),
            REVISION);
    }

//---PRIVATE METHODS---

//---ACCESSOR/MUTATOR METHODS---
    
    /**
     * Returns a reference to a specific Queue for this
     * monitor. This Queue returns only the data packets
     * (based on type) that we want too look at.
     *
     * @return a reference to a Queue
     */
    protected Queue getQueue() {
        return MonitorManager.getInstance().getAllQueue();
    }
    
    /**
     * Gets us a queue within the Queue we're using.
     *
     * @return a unique queue id number
     */
    protected int getQueueId() {
        if (_qID == -1) {
            _qID = getQueue().getQueue();
        }
        return _qID;
    }
    
//---ATTRIBUTES---
    
    /**
     * This is the friendly identifier of the
     * component this class is running in.
     * eg, a Filter may be called "filter1",
     * If this class does not have an owning
     * component,  a name from the configuration
     * can be placed here.  This name could also
     * be changed to null for utility classes.
     */
    private String _name = "WebFeeder";

    /**
     * This holds a reference to the
     * system logger that is being used.
     */
    private Logger _logger = ReferenceManager.getInstance().getLogger();
    
    /**
     * Holds our queue ID number. Starts with -1, which
     * indicates we don't have a queue.
     */
    protected int _qID = -1;
    
    /**
     * A flag so we can stop if required.
     */
    protected boolean _running = true;

//---STATIC ATTRIBUTES---

}
