/* 
 * i-scream central monitoring system
 * http://www.i-scream.org.uk
 * Copyright (C) 2000-2002 i-scream
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

//---PACKAGE DECLARATION---
package uk.org.iscream.cms.server.dbinterface;

//---IMPORTS---
import uk.org.iscream.cms.util.*;
import uk.org.iscream.cms.server.core.*;
import uk.org.iscream.cms.server.clientinterface.*;
import uk.org.iscream.cms.server.componentmanager.*;

/**
 * Starts the database interface
 * This interface places inbound data into a database.
 * This is an i-scream component.
 *
 * @author  $Author: tdb $
 * @version $Id: DBInterface.java,v 1.18 2003/02/05 16:43:47 tdb Exp $
 */
public class DBInterface implements Component {

//---FINAL ATTRIBUTES---

    /**
     * The current CVS revision of this class
     */
    public static final String REVISION = "$Revision: 1.18 $";
    
//---STATIC METHODS---

//---CONSTRUCTORS---

//---PUBLIC METHODS---

    /**
     * Starts the db interface
     */
    public void start() throws ComponentStartException {
        // get references to key objects
        _logger = _refman.getLogger();
        
        _logger.write(toString(), Logger.SYSINIT, "coming up");
        
        ConfigurationProxy cp = ConfigurationProxy.getInstance();
        String configName = "DBInterface";
        
        // set our name
        try {
            NAME = cp.getProperty(configName, "DBInterface.name");
        } catch (PropertyNotFoundException e) {
            NAME = null;
            _logger.write(toString(), Logger.WARNING, "DBInterface name not set: "+e);
        }
        
        _logger.write(toString(), Logger.SYSINIT, "configured");
        
        // setup a queue
        Queue queue;
        // see if this Queue needs a size limit
        try {
            int queueSizeLimit = Integer.parseInt(cp.getProperty(configName, "Queue.SizeLimit"));
            String queueRemoveAlgorithm = cp.getProperty(configName, "Queue.RemoveAlgorithm");
            int algorithm = StringUtils.getStringPos(queueRemoveAlgorithm, Queue.algorithms);
            if(algorithm != -1) {
                _logger.write(toString(), Logger.DEBUG, "Starting Queue with size limit of "+queueSizeLimit+", using remove algorithm "+queueRemoveAlgorithm);
                // we have valid values, so lets start it.
                queue = new Queue(queueSizeLimit, algorithm);
            }
            else {
                _logger.write(toString(), Logger.WARNING, "Bad Queue Algorithm configuration, not known: "+queueRemoveAlgorithm);
                // just don't activate a limit
                queue = new Queue();
            }
        } catch (PropertyNotFoundException e) {
            _logger.write(toString(), Logger.DEBUG, "Optional config not set: "+e);
            // just don't activate a limit
            queue = new Queue();
        } catch (NumberFormatException e) {
            _logger.write(toString(), Logger.WARNING, "Bad Queue SizeLimit configuration: "+e);
            // just don't activate a limit
            queue = new Queue();
        }
        
        // CDBServant start (for inbound data)
        _logger.write(toString(), Logger.DEBUG, "starting servant for inbound data");
        DBServant dbServant = new DBServant(queue);
        _refman.bindToOrb(dbServant, "iscream.ClientInterface\\." + DBInterface.NAME);
        
        // DBInserter Thread start
        DBInserter dbInserter = new DBInserter(queue);
        dbInserter.start();
        
        _logger.write(toString(), Logger.SYSINIT, "started");
    }
    
    /**
     * Does a dependency check. Used mainly at startup to
     * see if the required dependencies (components) are up
     * and running.
     *
     * @return a boolean value, true if the depdencies are satisfied
     */
    public boolean depCheck() {
        try {
            org.omg.CORBA.Object obj;
            obj = _refman.getCORBARef("iscream.Logger");
            obj = _refman.getCORBARef("iscream.ConfigurationManager");
        } catch(ComponentCORBAException e) {
            System.err.println(toString() + ": Dependency Failure: "+e);
            return false;
        }
        // dependency check suceeded
        return true;
    }
    
    /**
     * Overrides the {@link java.lang.Object#toString() Object.toString()}
     * method to provide clean logging (every class should have this).
     *
     * This uses the uk.org.iscream.cms.util.NameFormat class
     * to format the toString()
     *
     * @return the name of this class and its CVS revision
     */
    public String toString() {
        return FormatName.getName(
            NAME,
            this.getClass().getName(),
            REVISION);
    }

//---PRIVATE METHODS---

//---ACCESSOR/MUTATOR METHODS---

//---ATTRIBUTES---

    /**
     * This holds a reference to the
     * system logger that is being used.
     */
    private Logger _logger;

    /**
     * A reference to the reference manager in use
     */
    private ReferenceManager _refman = ReferenceManager.getInstance();

//---STATIC ATTRIBUTES---

    /**
     * The friendly name for this component, used by
     * all related classes.
     * This is set from the configuration.
     */
    public static String NAME;

}            
