/* 
 * i-scream central monitoring system
 * http://www.i-scream.org.uk
 * Copyright (C) 2000-2002 i-scream
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

//---PACKAGE DECLARATION---
package uk.org.iscream.cms.server.dbinterface;

//---IMPORTS---
import uk.org.iscream.cms.util.*;
import uk.org.iscream.cms.server.componentmanager.*;

/**
 * Wraps an XMLPacket, an XML String, and a time in a single Object.
 *
 * @author  $Author: tdb $
 * @version $Id: XMLPacketWrapper.java,v 1.7 2003/02/05 16:43:47 tdb Exp $
 */
class XMLPacketWrapper {

//---FINAL ATTRIBUTES---

    /**
     * The current CVS revision of this class
     */
    public static final String REVISION = "$Revision: 1.7 $";
    
//---STATIC METHODS---

//---CONSTRUCTORS---
    
    /**
     * Constructs an XMLPacketWrapper on the given XML data.
     *
     * @throws InvalidXMLException if the xml is not valid
     */
    public XMLPacketWrapper(String xml) throws InvalidXMLException {
        _xml = xml;
        _timestamp = System.currentTimeMillis()/1000;
        _packet = _xmlCache.getXMLPacket(xml);
    }

//---PUBLIC METHODS---

    /**
     * Overrides the {@link java.lang.Object#toString() Object.toString()}
     * method to provide clean logging (every class should have this).
     *
     * This uses the uk.ac.ukc.iscream.util.FormatName class
     * to format the toString()
     *
     * @return the name of this class and its CVS revision
     */
    public String toString() {
        return FormatName.getName(
            _name,
            getClass().getName(),
            REVISION);
    }

//---PRIVATE METHODS---

//---ACCESSOR/MUTATOR METHODS---
    
    /**
     * Returns the XML data as an XMLPacket Object.
     *
     * @return an XMLPacket representing the XML data
     */
    public XMLPacket getXMLPacket() {
        return _packet;
    }
    
    /**
     * Returns the XML data as a raw String.
     *
     * @return a String representing the XML data
     */
    public String getXML() {
        return _xml;
    }
    
    /**
     * Returns the timestamp of when this XML was received.
     *
     * @return a long time since the epoch
     */
    public long getTimestamp() {
        return _timestamp;
    }

//---ATTRIBUTES---
    
    /**
     * The XMLPacket version of the _xml String.
     */
    private XMLPacket _packet;
    
    /**
     * The String of XML date this object represents.
     */
    private String _xml;
    
    /**
     * A timestamp at which the XML data was received
     * by the DBInterface section of the server.
     */
    private long _timestamp;

    /**
     * This is the friendly identifier of the
     * component this class is running in.
     * eg, a Filter may be called "filter1",
     * If this class does not have an owning
     * component,  a name from the configuration
     * can be placed here.  This name could also
     * be changed to null for utility classes.
     */
    private String _name = "XMLPacketWrapper";

//---STATIC ATTRIBUTES---

    /**
     * A reference to the XMLCache in use
     */
    private static XMLCache _xmlCache = XMLCache.getInstance();

}
