/* 
 * i-scream central monitoring system
 * http://www.i-scream.org.uk
 * Copyright (C) 2000-2002 i-scream
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

//---PACKAGE DECLARATION---
package uk.org.iscream.cms.server.rootfilter;

//---IMPORTS---
import uk.org.iscream.cms.server.core.*;
import uk.org.iscream.cms.server.componentmanager.*;
import uk.org.iscream.cms.server.clientinterface.*;
import uk.org.iscream.cms.util.*;

/**
 * A ClientInterface wrapper - the CI objects are pushed data,
 * yet data is pulled from the queue. This will sit inbetween
 * for now, until the CI design is changed.
 *
 * @author  $Author: tdb $
 * @version $Id $
 */
public class CIWrapper extends Thread {

//---FINAL ATTRIBUTES---

    /**
     * The current CVS revision of this class
     */
    public final String REVISION = "$Revision: 1.14 $";
    
//---STATIC METHODS---

//---CONSTRUCTORS---

    /**
     * Sets up the wrapper, with a single destination and a queue.
     *
     * @param destination the client interface to send the xml to
     * @param queue a reference to a queue to use
     */
    public CIWrapper(ClientInterface destination, Queue queue){
        // set the Thread name
        setName("rootfilter.CIWrapper");
        
        _destination = destination;
        _queue = queue;
        _queueID = queue.getQueue();
    }

//---PUBLIC METHODS---

    /**
     * start the thread and thus gets and sends data
     */
    public void run() {
        String xml = null;
        boolean run = true;
        while(run) {
            // get a line of XML from the queue
            try {
                xml = (String) _queue.get(_queueID);
            }
            catch (InvalidQueueException e) {
                _logger.write(toString(), Logger.ERROR, "Queue error: "+e);
            }
            // pass it on to the destination
            try {
                _destination.receiveXML(xml);
            }
            catch (org.omg.CORBA.COMM_FAILURE e) {
                run = false;
                _logger.write(toString(), Logger.ERROR, "Connection failure (COMM_FAILURE), client interface shutdown? : "+e);
            }
            catch (org.omg.CORBA.TRANSIENT e) {
                run = false;
                _logger.write(toString(), Logger.ERROR, "Connection failure (TRANSIENT), client interface shutdown? : "+e);
            }
        }
        // looks like something when wrong in communication
        // rather than fall over in a heap, lets just stop
        // cleanly and shutdown our queue...
        _logger.write(toString(), Logger.SYSMSG, "Shutting Down...");
        _queue.removeQueue(_queueID);
    }

    /**
     * Overrides the {@link java.lang.Object#toString() Object.toString()}
     * method to provide clean logging (every class should have this).
     *
     * This uses the uk.org.iscream.cms.util.NameFormat class
     * to format the toString()
     *
     * @return the name of this class and its CVS revision
     */
    public String toString() {
        return FormatName.getName(
            _name,
            getClass().getName(),
            REVISION);
    }

//---PRIVATE METHODS---

//---ACCESSOR/MUTATOR METHODS---

//---ATTRIBUTES---

    /**
     * A reference to a Queue object.
     */
    private Queue _queue;
    
    /**
     * Our Queue id.
     */
    private int _queueID;
    
    /**
     * the interface this thread is sending data to
     */
    private ClientInterface _destination;
    
    /**
     * This is the friendly identifier of the
     * component this class is running in.
     * eg, a Filter may be called "filter1",
     * If this class does not have an owning
     * component,  a name from the configuration
     * can be placed here.  This name could also
     * be changed to null for utility classes.
     */
    private String _name = RootFilter.NAME;

    /**
     * This holds a reference to the
     * system logger that is being used.
     */
    private Logger _logger = ReferenceManager.getInstance().getLogger();

//---STATIC ATTRIBUTES---

}
